==> map-0.24.jar: PaintTyome.java <==
import java.awt.*;
import java.util.*;

/*
 * : 2004/01/09
 */

/**
 * Ͽޤñ̤ɤʬ륯饹Ǥ
 * @author Kumano Tatsuo
 */
class PaintTyome {

	private boolean isChanged;

	/**
	 * Ͽޤñ̤ɤʬޤ
	 * Υ᥽åɤƤӽФľ isChanged() ƤӽФȡ
	 * Υ᥽åɤˤäϿޤξ֤ѲɤǤޤ
	 * @param maps Ͽ
	 */
	void paintTyome(Map maps) throws Exception {
		isChanged=false;
		Map attributePolygonMap = new HashMap(); // String -> Collection<Polygon>  Map
		// °򥭡ݥꥴνͤȤ Map 
		for (Iterator iter = maps.values().iterator(); iter.hasNext();) {
			MapData mapData = (MapData) iter.next();
			if (mapData.hasTyome()) {
				for (Iterator iter2 = mapData.getTyome().values().iterator(); iter2.hasNext();) {
					Polygon polygon = (Polygon) iter2.next();
					String attribute = polygon.getAttribute();
					if (attribute != null) {
						if (!attributePolygonMap.containsKey(attribute)) {
							attributePolygonMap.put(attribute, new ArrayList());
						}
						((Collection) attributePolygonMap.get(attribute)).add(polygon);
					}
				}
			}
		}
		//System.out.println("attribute <-> polygon = " + attributePolygonMap);
		// Polygon 򥭡Collection<Polygon> ͤȤ Map 
		Map adjacentGraph = new HashMap();
		for (Iterator iter = maps.values().iterator(); iter.hasNext();) {
			MapData mapData = (MapData) iter.next();
			if (mapData.hasTyome()) {
				Map adjacentPolygons = mapData.getAdjacentGraph();
				for (Iterator iter2 = adjacentPolygons.keySet().iterator(); iter2.hasNext();) {
					String polygonName = (String) iter2.next();
					adjacentGraph.put(mapData.getTyome().get(polygonName), adjacentPolygons.get(polygonName));
				}
			}
		}
		//System.out.println("ܥա" + adjacentGraph);
		// ɤʬ
		for (Iterator iter = maps.values().iterator(); iter.hasNext();) {
			MapData mapData = (MapData) iter.next();
			if (mapData.hasTyome()) {
				for (Iterator iter2 = mapData.getTyome().values().iterator(); iter2.hasNext();) {
					Polygon polygon = (Polygon) iter2.next();
					if (polygon.getPolygonName() != null) {
						fixColorRecursively(polygon, adjacentGraph, attributePolygonMap);
					}
				}
			}
		}
	}

	/**
	 * ľɤʬǡϿޤξ֤Ѳɤޤ
	 * @return Ͽޤξ֤Ѳɤ
	 */
	boolean isChanged() {
		return isChanged;
	}

	/**
	 * ꤷݥꥴοƵŪ˷ꤷޤ
	 * red, green, blue, yellow, magenda, cyan ν˿ޤ 
	 * @param polygon ݥꥴ
	 * @param adjacentGraph ܥ
	 * @param attributePolygonMap °ȥݥꥴδϢŤ
	 */
	private void fixColorRecursively(Polygon polygon, Map adjacentGraph, Map attributePolygonMap) {
		if (polygon.getFillColor() != null) {
			return;
		}
		Collection usedColors = new HashSet();
		addUsedColors(polygon, adjacentGraph, usedColors);
		String attribute = polygon.getAttribute();
		if (attribute != null) {
			if (attributePolygonMap.containsKey(attribute)) {
				for (Iterator iter = ((Collection) attributePolygonMap.get(attribute)).iterator();
					iter.hasNext();
					) {
					Polygon polygon2 = (Polygon) iter.next();
					if (polygon != polygon2) {
						addUsedColors(polygon2, adjacentGraph, usedColors);
					}
				}
			}
		}
		if (!usedColors.contains(MapColor.TYOME_YELLOW)) {
			polygon.setFillColor(MapColor.TYOME_YELLOW);
		} else if (!usedColors.contains(MapColor.TYOME_CYAN)) {
			polygon.setFillColor(MapColor.TYOME_CYAN);
		} else if (!usedColors.contains(MapColor.TYOME_GREEN)) {
			polygon.setFillColor(MapColor.TYOME_GREEN);
		} else if (!usedColors.contains(MapColor.TYOME_BLUE)) {
			polygon.setFillColor(MapColor.TYOME_BLUE);
		} else if (!usedColors.contains(MapColor.TYOME_MAGENTA)) {
			polygon.setFillColor(MapColor.TYOME_MAGENTA);
		} else if (!usedColors.contains(MapColor.TYOME_RED)) {
			polygon.setFillColor(MapColor.TYOME_RED);
		} else if (!usedColors.contains(Color.GREEN)) {
			polygon.setFillColor(Color.GREEN);
		//} else if (!usedColors.contains(MapColor.TYOME_ORANGE)) {
			//polygon.setFillColor(MapColor.TYOME_ORANGE);
		} else {
			//polygon.setFillColor(MapColor.TYOME_DARK_GREEN);
			polygon.setFillColor(Color.RED);
		}
		isChanged=true;
		if (attribute != null) {
			if (attributePolygonMap.containsKey(attribute)) {
				for (Iterator iter = ((Collection) attributePolygonMap.get(attribute)).iterator();
					iter.hasNext();
					) {
					Polygon polygon2 = (Polygon) iter.next();
					if (polygon != polygon2) {
						polygon2.setFillColor(polygon.getFillColor());
					}
				}
			}
		}
		if (adjacentGraph.containsKey(polygon)) {
			for (Iterator iter = ((Collection) adjacentGraph.get(polygon)).iterator(); iter.hasNext();) {
				Polygon polygon2 = (Polygon) iter.next();
				fixColorRecursively(polygon2, adjacentGraph, attributePolygonMap);
			}
		}
	}

	private void addUsedColors(Polygon polygon, Map adjacentGraph, Collection usedColors) {
		if (adjacentGraph.containsKey(polygon)) {
			for (Iterator iter1 = ((Collection) adjacentGraph.get(polygon)).iterator(); iter1.hasNext();) {
				Polygon polygon21 = (Polygon) iter1.next();
				Color color = polygon21.getFillColor();
				if (color != null) {
					usedColors.add(color);
				}
			}
		}
	}

}

==> map-0.27.jar: PaintTyome.java <==
import java.awt.*;
import java.util.*;

/*
 * : 2004/01/09
 */

/**
 * Ͽޤñ̤ɤʬ륯饹Ǥ
 * @author Kumano Tatsuo
 */
class PaintTyome {

	private boolean isChanged;

	/** Ͽޤñ̤ɤʬޤ
         * Υ᥽åɤƤӽФľ isChanged() ƤӽФȡ
         * Υ᥽åɤˤäϿޤξ֤ѲɤǤޤ
         * @param maps Ͽ
         * @throws Exception 㳰
         */
	void paintTyome(Map maps) throws Exception {
		isChanged=false;
		Map attributePolygonMap = new HashMap(); // String -> Collection<Polygon>  Map
		// °򥭡ݥꥴνͤȤ Map 
		for (Iterator iter = maps.values().iterator(); iter.hasNext();) {
			MapData mapData = (MapData) iter.next();
			if (mapData.hasTyome()) {
				for (Iterator iter2 = mapData.getTyome().values().iterator(); iter2.hasNext();) {
					PolygonData polygon = (PolygonData) iter2.next();
					String attribute = polygon.getAttribute();
					if (attribute != null) {
						if (!attributePolygonMap.containsKey(attribute)) {
							attributePolygonMap.put(attribute, new ArrayList());
						}
						((Collection) attributePolygonMap.get(attribute)).add(polygon);
					}
				}
			}
		}
		//System.out.println("attribute <-> polygon = " + attributePolygonMap);
		// Polygon 򥭡Collection<Polygon> ͤȤ Map 
		Map adjacentGraph = new HashMap();
		for (Iterator iter = maps.values().iterator(); iter.hasNext();) {
			MapData mapData = (MapData) iter.next();
			if (mapData.hasTyome()) {
				Map adjacentPolygons = mapData.getAdjacentGraph();
				for (Iterator iter2 = adjacentPolygons.keySet().iterator(); iter2.hasNext();) {
					String polygonName = (String) iter2.next();
					adjacentGraph.put(mapData.getTyome().get(polygonName), adjacentPolygons.get(polygonName));
				}
			}
		}
		//System.out.println("ܥա" + adjacentGraph);
		// ɤʬ
		for (Iterator iter = maps.values().iterator(); iter.hasNext();) {
			MapData mapData = (MapData) iter.next();
			if (mapData.hasTyome()) {
				for (Iterator iter2 = mapData.getTyome().values().iterator(); iter2.hasNext();) {
					PolygonData polygon = (PolygonData) iter2.next();
					if (polygon.getPolygonName() != null) {
						fixColorRecursively(polygon, adjacentGraph, attributePolygonMap);
					}
				}
			}
		}
	}

	/**
	 * ľɤʬǡϿޤξ֤Ѳɤޤ
	 * @return Ͽޤξ֤Ѳɤ
	 */
	boolean isChanged() {
		return isChanged;
	}

	/**
	 * ꤷݥꥴοƵŪ˷ꤷޤ
	 * red, green, blue, yellow, magenda, cyan ν˿ޤ 
	 * @param polygon ݥꥴ
	 * @param adjacentGraph ܥ
	 * @param attributePolygonMap °ȥݥꥴδϢŤ
	 */
	private void fixColorRecursively(PolygonData polygon, Map adjacentGraph, Map attributePolygonMap) {
		if (polygon.getFillColor() != null) {
			return;
		}
		Collection usedColors = new HashSet();
		addUsedColors(polygon, adjacentGraph, usedColors);
		String attribute = polygon.getAttribute();
		if (attribute != null) {
			if (attributePolygonMap.containsKey(attribute)) {
				for (Iterator iter = ((Collection) attributePolygonMap.get(attribute)).iterator();
					iter.hasNext();
					) {
					PolygonData polygon2 = (PolygonData) iter.next();
					if (polygon != polygon2) {
						addUsedColors(polygon2, adjacentGraph, usedColors);
					}
				}
			}
		}
		if (!usedColors.contains(MapColor.TYOME_YELLOW)) {
			polygon.setFillColor(MapColor.TYOME_YELLOW);
		} else if (!usedColors.contains(MapColor.TYOME_CYAN)) {
			polygon.setFillColor(MapColor.TYOME_CYAN);
		} else if (!usedColors.contains(MapColor.TYOME_GREEN)) {
			polygon.setFillColor(MapColor.TYOME_GREEN);
		} else if (!usedColors.contains(MapColor.TYOME_BLUE)) {
			polygon.setFillColor(MapColor.TYOME_BLUE);
		} else if (!usedColors.contains(MapColor.TYOME_MAGENTA)) {
			polygon.setFillColor(MapColor.TYOME_MAGENTA);
		} else if (!usedColors.contains(MapColor.TYOME_RED)) {
			polygon.setFillColor(MapColor.TYOME_RED);
		} else if (!usedColors.contains(Color.GREEN)) {
			polygon.setFillColor(Color.GREEN);
		//} else if (!usedColors.contains(MapColor.TYOME_ORANGE)) {
			//polygon.setFillColor(MapColor.TYOME_ORANGE);
		} else {
			//polygon.setFillColor(MapColor.TYOME_DARK_GREEN);
			polygon.setFillColor(Color.RED);
		}
		isChanged=true;
		if (attribute != null) {
			if (attributePolygonMap.containsKey(attribute)) {
				for (Iterator iter = ((Collection) attributePolygonMap.get(attribute)).iterator();
					iter.hasNext();
					) {
					PolygonData polygon2 = (PolygonData) iter.next();
					if (polygon != polygon2) {
						polygon2.setFillColor(polygon.getFillColor());
					}
				}
			}
		}
		if (adjacentGraph.containsKey(polygon)) {
			for (Iterator iter = ((Collection) adjacentGraph.get(polygon)).iterator(); iter.hasNext();) {
				PolygonData polygon2 = (PolygonData) iter.next();
				fixColorRecursively(polygon2, adjacentGraph, attributePolygonMap);
			}
		}
	}

	private void addUsedColors(PolygonData polygon, Map adjacentGraph, Collection usedColors) {
		if (adjacentGraph.containsKey(polygon)) {
			for (Iterator iter1 = ((Collection) adjacentGraph.get(polygon)).iterator(); iter1.hasNext();) {
				PolygonData polygon21 = (PolygonData) iter1.next();
				Color color = polygon21.getFillColor();
				if (color != null) {
					usedColors.add(color);
				}
			}
		}
	}

}
